Justice League Vigil for Slain NYPD Officers Asks Whose Life Matters - The Daily Beast
Author: http://www.thedailybeast.com/contributors/olivia-nuzzihtml
Description: At a peaceful gathering of the Justice League, they condemned the killings of Officers Liu and Ramos, but also wondered why the slaying of citizens by cops doesn’t spark as much outrage.
Keywords: new york city
Date: 2014-12-22T10:39:00.000Z

Mike Segar/Reuters

Olivia Nuzzi

- facebook
- tweet
- post

### MIXED FEELINGS

12.22.14

# Justice League Vigil for Slain NYPD Officers Asks Whose Life Matters

At a peaceful gathering of the Justice League, they condemned the killings of Officers Liu and Ramos, but also wondered why the slaying of citizens by cops doesn’t spark as much outrage.

A modest crowd moved East on 110th Street in New York City on Sunday evening. They walked silently, some carrying Anthora cups illuminated by candlesticks, others holding plastic tea lights handed out by protest organizers. A few carried signs: "IMAGINE JUSTICE," "BLACK LIVES MATTER," "CLAIM HUMANITY." But mostly they just walked, their faces somber, their hands shaking as the snow began to fall.

The peaceful vigil was somewhat unexpected, given the heightened tensions between protesters as the NYPD in recent weeks, culminating in the murder of two officers in Bed-Stuy on Saturday afternoon.

Just over 24 hours before the silent march down 110th, Wenjian Liu, 32, and Rafael Ramos, 40, had been shot "execution-style," Mayor Bill DeBlasio said, while sitting in their patrol car. The suspect, Ismaaiyl Brinsley, had begun the day with the shooting of his ex-girlfriend in Maryland before taking the trip up to New York, armed with a silver semi-automatic handgun. After murdering the officers, Brinsley walked over to a subway platform where he turned the weapon on himself.

In some ways, the tragedy seemed inevitable.

As the nation continued to cope with Ferguson, a grand jury in Staten Island chose not to indict in the case of Eric Garner, a man choked to death –– as he pleaded "I can't breathe" –– by a police offer in what the coroner declared a homicide. #BlackLivesMatter has been the prevailing message as protesters have taken to the streets to express their outrage. They often chant: "No justice, no peace; No racist police."

All the while, there have been critics. Why, they ask, do black lives matter? Why not all lives? They contend that the protests are not anti-police brutality, but anti-police, period. They believe that the protesters and those who enabled them—the media, or De Blasio, who spoke frankly about how he talks to his biracial son, whose mother is black, about the threats he might face due to his skin color—have been vying for NYPD scalps. With two now dead, the critics are pointing fingers.

"The mayor’s hands are literally dripping with our blood because of his words, actions and policies and we have, for the first time in a number of years, become a 'wartime' police department," Pat Lynch, head of the police union, said at a press conference on Saturday night. "There's blood on many hands tonight…That blood on the hands starts at City Hall in the Office of the Mayor."

Former mayor Rudy Giuliani echoed the sentiment, but laid blame on President Obama: "We've had four months of propaganda starting with the president that everybody should hate the police…The protests are being embraced, the protests are being encouraged. The protests, even the ones that don't lead to violence—a lot of them lead to violence, all of them lead to a conclusion: The police are bad, the police are racist. That is completely wrong."

The march, organized by the Justice League NYC—effectively anointed by De Blasio as City Hall's preferred protest group with a 4-minute meeting to discuss theories of policing—continued slowly along 110th street, a police van humming alongside. The crowd snaked into Central Park, where it came to a stop at the boathouse, a lighted Christmas tree illuminating the water's surface.

"Let me not say this wrong," a 21-year-old East Flatbush resident who would say only that his name was "Perry" told me as he looked around, seemingly searching for the right words. "Yesterday's situation that happened in Brooklyn, Bed-Stuy, was uncalled for. It was the wrong way about handling it. Because we're upset that on our end, they're killing us, so I don't think nobody should go take the anger out on, you know—nobody knows these two specific individuals. They could've been good people. They could've been, you know, legit officers who wasn't down with whatever's going on. My condolences do go to their families. But at the same time, since Zimmerman, you've been hearing cases about officers killing black children—black men, Hispanic men.

"This is not about who did it more, but it's more: all these lives didn't matter, but now two cops are dead, and now it matters? If you look at the newspapers, it's all broadcast all over the place. The whole world's supposed to mourn because—don't get me wrong, it was wrong––but because two officers died, now the world's supposed to mourn? What happened to all the other people that died? Nobody mourned. They wasn't in the front page of newspapers. They was in back pages—some didn't even make the newspaper."

Next to "Perry" stood Jonathan Alvarez, 18, of Queens, who in November made headlines when he announced plans to sue the city after allegedly being assaulted by police officers for being a "smart guy."

"I got targeted. I'm a victim of police brutality," Alvarez told me. "They arrested me, they beat me up in the 102 precinct while I was handcuffed, no justice. So I feel for these people, I understand they're just brutes. They can get away with it, and they do…They don't give a fuck until one of them dies, that's all they care about."

"Perry" chimed in: "They don't want to take blame," he said of the police union attacking De Blasio. "There has to be peace on all sides.

"I think this all could've been prevented if they just listened to the 25,000 people who marched last week," Alvarez said. "No, not even," "Perry" countered: "If they would've just re-analyzed the Zimmerman case, or the Ferguson case."

Then, "Perry" and Alvarez went silent. The marchers began to stream out of the park, where they walked West on 110th and then hung a right on 7th Avenue. NYPD officers lingered, politely asking participants to move in the line, and saying "thank you" when they obliged, which they all did.

The march reached its conclusion at the First Corinthian Baptist Church on 116th street, where piano music befitting a funeral greeting guests who filed into the warm pews.

Religious leaders—Pastor Willie Francois III, the Rev. Mike Walrond, and the Rev. Stephen Phelps—and over a dozen activists, led by Justice League NYC's Tamika Mallory, took turns addressing the crowd.

There were prayers for 40 black men, beginning with Eric Garner, who had been killed by police; and prayers for De Blasio, who "is attacked on one side and the other," and repeated acknowledgement that violence is not the way to change what the protesters believe is a fundamentally broken system.

"We're not anti-police, we're anti-police brutality," a member of the Justice League told the crowd, to cheers. "Every cop isn't bad…Every black man isn't a criminal."

The crowd rose, embraced each other in groups of two and three, and prayed.